pub(crate) struct Opts {Show 19 fields
pub(crate) slice_us: u64,
pub(crate) dsq_topology: DsqTopology,
pub(crate) ordering: QueueOrdering,
pub(crate) idle_policy: IdlePolicy,
pub(crate) no_wake_sync: bool,
pub(crate) primary_domain: Option<String>,
pub(crate) enable_preemption: bool,
pub(crate) perf_config: PerfEventSpec,
pub(crate) perf_threshold: u64,
pub(crate) perf_sticky: PerfEventSpec,
pub(crate) perf_sticky_threshold: u64,
pub(crate) exit_dump_len: u32,
pub(crate) stats: Option<f64>,
pub(crate) monitor: Option<f64>,
pub(crate) debug: bool,
pub(crate) verbose: bool,
pub(crate) version: bool,
pub(crate) help_stats: bool,
pub libbpf: LibbpfOpts,
}Fields
slice_us: u64Maximum scheduling slice duration in microseconds.
dsq_topology: DsqTopologyTopology level of the user-created DSQs.
ordering: QueueOrderingOrdering algorithm for the queue key of vtime-ordered DSQs.
idle_policy: IdlePolicyWakeup idle-CPU selection policy.
no_wake_sync: boolDisable synchronous-wakeup bias during idle CPU selection.
primary_domain: Option<String>Specifies a list of CPUs to prioritize.
Accepts a comma-separated list of CPUs or ranges (i.e., 0-3,12-15) or the following special keywords:
“performance” = automatically detect and prioritize the fastest CPUs, “powersave” = automatically detect and prioritize the slowest CPUs, “all” = all CPUs assigned to the primary domain.
By default “all” CPUs are used.
enable_preemption: boolEnable preempting the running task when an eligible sleeper wakes up on its CPU.
perf_config: PerfEventSpecHardware/software perf event to monitor for the event-heavy migration hint (0x0 = disabled). Accepts hex (0xN) or a symbolic name (e.g. cache-misses, LLC-load-misses, page-faults, branch-misses).
perf_threshold: u64Threshold (events accumulated over a slice) above which a task is classified as event-heavy and biased toward migrating to an idle CPU. The behavior is gated on –perf-config.
perf_sticky: PerfEventSpecSticky perf event (0x0 = disabled). When a task exceeds –perf-sticky-threshold for this event, keep it on its previous CPU. Accepts hex (0xN) or a symbolic name.
perf_sticky_threshold: u64Sticky perf threshold; a task is kept on its previous CPU when its count for the –perf-sticky event exceeds this. The behavior is gated on –perf-sticky.
exit_dump_len: u32Exit debug dump buffer length. 0 indicates default.
stats: Option<f64>Enable stats monitoring with the specified interval.
monitor: Option<f64>Run in stats monitoring mode with the specified interval. Scheduler is not launched.
debug: boolEnable BPF debugging via /sys/kernel/tracing/trace_pipe.
verbose: boolEnable verbose output, including libbpf details.
version: boolPrint scheduler version and exit.
help_stats: boolShow descriptions for statistics.
libbpf: LibbpfOptsTrait Implementations
Sourceimpl Args for Opts
impl Args for Opts
Sourcefn group_id() -> Option<Id>
fn group_id() -> Option<Id>
ArgGroup::id][crate::ArgGroup::id] for this set of argumentsSourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Command] so it can instantiate self via
[FromArgMatches::update_from_arg_matches_mut] Read moreSourceimpl FromArgMatches for Opts
impl FromArgMatches for Opts
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourceimpl Parser for Opts
impl Parser for Opts
fn parse_from<I, T>(itr: I) -> Self
fn parse_from<I, T>(itr: I) -> Self
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn update_from<I, T>(&mut self, itr: I)
fn update_from<I, T>(&mut self, itr: I)
fn try_update_from<I, T>(&mut self, itr: I) -> Result<(), Error>
fn try_update_from<I, T>(&mut self, itr: I) -> Result<(), Error>